@@ -162,7 +162,7 @@ ScaleBivariate <- ggproto("ScaleBivariate",
                             }
 
                             breaks <- scales::censor(self$trans[[i]]$transform(breaks), self$trans[[i]]$transform(limits),
-                                             only.finite = FALSE)
+                                                     only.finite = FALSE)
                             breaks
                           },
 
@@ -341,14 +341,13 @@ pal_vsup <- function(values, unc_levels = 4, max_light = 0.9, max_desat = 0, pow
     u <- x$u # need maximum lightening for 0 certainty
 
     range01 <- function(x,a,b){
-       ((b-a)*((x-min(x)))/(max(x)-min(x)))+a
-     }
+      ((b-a)*((x-min(x)))/(max(x)-min(x)))+a
+    }
 
     # limit maximal desaturation and lightening
     des_amt <- max_desat*u^pow_desat
     light_amt <- max_light*u^pow_light
     cols_des <- colorspace::desaturate(ramp(v), des_amt)
-    #cols_des <- colorspace::lighten(ramp(v), range01(des_amt, 0, 0.9))
     nas <- is.na(light_amt)
     light_amt[nas] <- 0
     ifelse(nas, NA, colorspace::lighten(cols_des, light_amt, space = "HLS"))
@@ -510,18 +509,6 @@ guide_merge.colourfan <- function(guide, new_guide) {
 #'
 #' @export
 guide_geom.colourfan <- function(guide, layers, default_mapping) {
-  # Layers that use this guide
-  # guide_layers <- plyr::llply(layers, function(layer) {
-  #   matched <- matched_aes(layer, guide, default_mapping)
-  #
-  #   if (length(matched) && ((is.na(layer$show.legend) || layer$show.legend))) {
-  #     layer
-  #   } else {
-  #     # This layer does not use this guide
-  #     NULL
-  #   }
-  # })
-
   guide_layers <- lapply(layers, function(layer) {
     matched <- matched_aes(layer, guide, default_mapping)
 
@@ -534,7 +521,6 @@ guide_geom.colourfan <- function(guide, layers, default_mapping) {
   })
 
   # Remove this guide if no layer uses it
-  #if (length(plyr::compact(guide_layers)) == 0) guide <- NULL
   if (length(purrr::compact(guide_layers)) == 0) guide <- NULL
 
   guide
@@ -545,8 +531,10 @@ guide_gengrob.colourfan <- function(guide, theme) {
   title.x.position <- guide$title.x.position %||% "top"
   title.y.position <- guide$title.y.position %||% "right"
 
-  fanwidth <- width_cm(theme$legend.key.width * 5)
-  fanheight <- height_cm(theme$legend.key.height * 5)
+  # Use legend.key.size as a fallback, then a default unit if NULL
+  key_size <- theme$legend.key.size %||% unit(1, "lines")
+  fanwidth <- width_cm((theme$legend.key.width %||% key_size) * 5)
+  fanheight <- height_cm((theme$legend.key.height %||% key_size) * 5)
   nbreak <- nrow(guide$key)
 
   # make the fan grob (`grob.fan`)
@@ -577,7 +565,7 @@ guide_gengrob.colourfan <- function(guide, theme) {
 
   label.x.pos <- transform_radial(dplyr::tibble(x = tick.x.pos, y = 1), yoff = 0.04)
   label.y.pos <- transform_radial(dplyr::tibble(x = 1, y = tick.y.pos),
-                                 # yoff = 0,
+                                  # yoff = 0,
                                   xoff = 0.04)
 
   # get the label theme
@@ -951,12 +939,11 @@ ggname <- function (prefix, grob)
 # returns a zeroGrob and informs the user.
 #' @noRd
 #' @keywords internal
-#' @importFrom cli cli_inform
 element_render <- function (theme, element, ..., name = NULL)
 {
   el <- ggplot2::calc_element(element, theme)
   if (is.null(el)) {
-    cli::cli_inform("Theme element {.var {element}} is missing")
+    message(sprintf("Theme element '%s' is missing", element))
     return(ggplot2::zeroGrob())
   }
   grob <- ggplot2::element_grob(el, ...)
@@ -1215,7 +1202,6 @@ stop_unexpected_typeof_bartman <- function(x) {
 
 #' @noRd
 #' @keywords internal
-#' @importFrom vctrs vec_size_common vec_recycle
 rotate_just_alter <-
   function (angle, hjust, vjust)
   {
@@ -1228,10 +1214,15 @@ rotate_just_alter <-
       vjust <- match(vjust, c("bottom", "top")) - 1
       vjust[is.na(vjust)] <- 0.5
     }
-    size <- vctrs::vec_size_common(angle, hjust, vjust)
-    angle <-  vctrs::vec_recycle(angle, size)
-    hjust <-  vctrs::vec_recycle(hjust, size)
-    vjust <-  vctrs::vec_recycle(vjust, size)
+    #size <- vctrs::vec_size_common(angle, hjust, vjust)
+    size <- max(length(angle), length(hjust), length(vjust))
+    # angle <-  vctrs::vec_recycle(angle, size)
+    # hjust <-  vctrs::vec_recycle(hjust, size)
+    # vjust <-  vctrs::vec_recycle(vjust, size)
+    recycle <- function(x, size) rep(x, length.out = size)
+    angle <- recycle(angle, size)
+    hjust <- recycle(hjust, size)
+    vjust <- recycle(vjust, size)
     case <- findInterval(angle, c(0, 90, 180, 270, 360))
     hnew <- hjust
     vnew <- vjust
@@ -1249,18 +1240,17 @@ rotate_just_alter <-
 
 #' @noRd
 #' @keywords internal
-#' @importFrom cli cli_text cli_fmt
 #' @importFrom rlang caller_env
 as_cli_bartman <- function (..., env = rlang::caller_env())
 {
-  cli::cli_fmt(cli::cli_text(..., .envir = env))
+  message(sprintf(...))
 }
 
 
 #' @noRd
 #' @keywords internal
 justify_grobs <- function (grobs, x = NULL, y = NULL, hjust = 0.5, vjust = 0.5,
-                                 int_angle = 0, debug = FALSE)
+                           int_angle = 0, debug = FALSE)
 {
   if (!inherits(grobs, "grob")) {
     if (is.list(grobs)) {
@@ -1286,10 +1276,10 @@ justify_grobs <- function (grobs, x = NULL, y = NULL, hjust = 0.5, vjust = 0.5,
     children = grid::gList(grobs)
   }
   result_grob <-  grid::gTree(children = children, vp = grid::viewport(x = x,
-                                                                 y = y,
-                                                                 width = grid::grobWidth(grobs),
-                                                                 height = grid::grobHeight(grobs),
-                                                                 just = unlist(just)))
+                                                                       y = y,
+                                                                       width = grid::grobWidth(grobs),
+                                                                       height = grid::grobHeight(grobs),
+                                                                       just = unlist(just)))
   if (isTRUE(debug)) {
     grid::grobTree(result_grob, grid::pointsGrob(x, y, pch = 20, gp = grid::gpar(col = "mediumturquoise")))
   }
@@ -1308,5 +1298,3 @@ justify_grobs <- function (grobs, x = NULL, y = NULL, hjust = 0.5, vjust = 0.5,
 is.waive <- function(x) {
   inherits(x, "waiver")
 }
-
-
