@@ -31,7 +31,7 @@
 #'  plot <- treeBarPlot(trees = trees_data, topTrees = 3, removeStump = TRUE)
 #' }
 #'
-#' @importFrom dplyr mutate pull group_by arrange filter slice n
+#' @importFrom dplyr mutate pull group_by arrange filter slice n as_tibble
 #' @importFrom purrr map imap
 #' @importFrom tidyr replace_na
 #' @import ggplot2
@@ -48,9 +48,22 @@ treeBarPlot <- function(trees, iter = NULL, topTrees = NULL, removeStump = FALSE
 
     # Optionally remove stumps
     if (removeStump) {
-      treeList <- Filter(function(x) igraph::gsize(x) > 0, treeList)
+      # 1. For each tree, activate the edges.
+      # 2. Convert the edge data to a tibble.
+      # 3. Check if the number of rows in the edge tibble is greater than 0.
+      treeList <- Filter(function(x) {
+        x %>%
+          tidygraph::activate(edges) %>%
+          as_tibble() %>%
+          nrow() > 0
+      }, treeList)
     }
 
+
+    # if (removeStump) {
+    #   treeList <- Filter(function(x) igraph::gsize(x) > 0, treeList)
+    # }
+
     # Get frequencies of similar trees
     freqs <- purrr::map(treeList, function(x) {
       x |>
@@ -97,8 +110,22 @@ treeBarPlot <- function(trees, iter = NULL, topTrees = NULL, removeStump = FALSE
       theme(legend.position = "none") +
       coord_flip()
 
+
+# STUMPS  -----------------------------------------------------------------
+
+    is_stump <- which(
+      sapply(treeList, function(tree) {
+        nrow(activate(tree, edges) %>% as_tibble()) == 0
+      })
+    )
+
     # find if any stumps
-    is_stump <- which(sapply(treeList, function(tree) igraph::gsize(tree) == 0))
+    #is_stump <- which(sapply(treeList, function(tree) igraph::gsize(tree) == 0))
+
+
+# -------------------------------------------------------------------------
+
+
     # Optional stump processing
     if(length(is_stump) >= 1){
       if (!removeStump) {
@@ -148,7 +175,7 @@ treeBarPlot <- function(trees, iter = NULL, topTrees = NULL, removeStump = FALSE
     # fix for getting the legend
     get_legend_35 <- function(plot) {
       # return all legend candidates
-      legends <- get_plot_component(plot, "guide-box", return_all = TRUE)
+      legends <- cowplot::get_plot_component(plot, "guide-box", return_all = TRUE)
       # find non-zero legends
       nonzero <- vapply(legends, \(x) !inherits(x, "zeroGrob"), TRUE)
       idx <- which(nonzero)
@@ -199,7 +226,7 @@ treeBarPlot <- function(trees, iter = NULL, topTrees = NULL, removeStump = FALSE
     bp1 <- bp + theme(axis.text.y = element_blank())
     ppp <- p_axis + theme(aspect.ratio = 10)
     px <- ppp | bp1
-    bpFinal <- cowplot::plot_grid(px, legend, rel_heights = c(1, .1), ncol = 1)
+    bpFinal <- cowplot::plot_grid(px, legend[[1]], rel_heights = c(1, .1), ncol = 1)
 
     return(bpFinal)
   })
